@@ -201,16 +201,24 @@ qprintnum(NUMBER *q, int outmode, LEN outdigits)
 	}
 	switch (outmode) {
 	case MODE_INT:
-		if (conf->tilde_ok && qisfrac(q))
+		if (conf->tilde_ok && qisfrac(q)) {
 			PUTCHAR('~');
+			if (conf->tilde_space && qisfrac(q)) {
+				PUTCHAR(' ');
+			}
+		}
 		qprintfd(q, 0L);
 		break;
 
 	case MODE_REAL:
 		prec = qdecplaces(q);
 		if ((prec < 0) || (prec > outdigits)) {
-			if (conf->tilde_ok)
+			if (conf->tilde_ok) {
 			    PUTCHAR('~');
+			    if (conf->tilde_space) {
+				PUTCHAR(' ');
+			    }
+			}
 		}
 		if (conf->fullzero || (prec < 0) ||
 		    (prec > outdigits))
@@ -412,7 +420,13 @@ qprintfr(NUMBER *q, long width, BOOL force)
 {
 	zprintval(q->num, 0L, width);
 	if (force || qisfrac(q)) {
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		PUTCHAR('/');
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		zprintval(q->den, 0L, width);
 	}
 }
@@ -446,7 +460,13 @@ qprintfx(NUMBER *q, long width)
 {
 	zprintx(q->num, width);
 	if (qisfrac(q)) {
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		PUTCHAR('/');
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		zprintx(q->den, 0L);
 	}
 }
@@ -461,7 +481,13 @@ qprintfb(NUMBER *q, long width)
 {
 	zprintb(q->num, width);
 	if (qisfrac(q)) {
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		PUTCHAR('/');
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		zprintb(q->den, 0L);
 	}
 }
@@ -476,7 +502,13 @@ qprintfo(NUMBER *q, long width)
 {
 	zprinto(q->num, width);
 	if (qisfrac(q)) {
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		PUTCHAR('/');
+		if (conf->fraction_space) {
+		    PUTCHAR(' ');
+		}
 		zprinto(q->den, 0L);
 	}
 }
@@ -749,6 +781,12 @@ fitprint(NUMBER *q, long width)
 		width1 = width - width2;
 	}
 	fitzprint(q->num, numdigits, width1);
+	if (conf->fraction_space) {
+	    PUTCHAR(' ');
+	}
 	PUTCHAR('/');
+	if (conf->fraction_space) {
+	    PUTCHAR(' ');
+	}
 	fitzprint(q->den, dendigits, width2);
 }
